@@ -1,7 +1,7 @@
 """
 Type annotations for appsync service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/type_defs.html)
+[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_appsync/type_defs/)
 
 Usage::
 
@@ -112,22 +112,29 @@ __all__ = (
     "LambdaAuthorizerConfigTypeDef",
     "LambdaConflictHandlerConfigTypeDef",
     "LambdaDataSourceConfigTypeDef",
+    "ListApiKeysRequestListApiKeysPaginateTypeDef",
     "ListApiKeysRequestRequestTypeDef",
     "ListApiKeysResponseTypeDef",
+    "ListDataSourcesRequestListDataSourcesPaginateTypeDef",
     "ListDataSourcesRequestRequestTypeDef",
     "ListDataSourcesResponseTypeDef",
     "ListDomainNamesRequestRequestTypeDef",
     "ListDomainNamesResponseTypeDef",
+    "ListFunctionsRequestListFunctionsPaginateTypeDef",
     "ListFunctionsRequestRequestTypeDef",
     "ListFunctionsResponseTypeDef",
+    "ListGraphqlApisRequestListGraphqlApisPaginateTypeDef",
     "ListGraphqlApisRequestRequestTypeDef",
     "ListGraphqlApisResponseTypeDef",
+    "ListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef",
     "ListResolversByFunctionRequestRequestTypeDef",
     "ListResolversByFunctionResponseTypeDef",
+    "ListResolversRequestListResolversPaginateTypeDef",
     "ListResolversRequestRequestTypeDef",
     "ListResolversResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
     "ListTagsForResourceResponseTypeDef",
+    "ListTypesRequestListTypesPaginateTypeDef",
     "ListTypesRequestRequestTypeDef",
     "ListTypesResponseTypeDef",
     "LogConfigTypeDef",
@@ -783,6 +790,14 @@ LambdaDataSourceConfigTypeDef = TypedDict(
     },
 )
 
+ListApiKeysRequestListApiKeysPaginateTypeDef = TypedDict(
+    "ListApiKeysRequestListApiKeysPaginateTypeDef",
+    {
+        "apiId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListApiKeysRequestRequestTypeDef = TypedDict(
     "ListApiKeysRequestRequestTypeDef",
     {
@@ -801,6 +816,14 @@ ListApiKeysResponseTypeDef = TypedDict(
     },
 )
 
+ListDataSourcesRequestListDataSourcesPaginateTypeDef = TypedDict(
+    "ListDataSourcesRequestListDataSourcesPaginateTypeDef",
+    {
+        "apiId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListDataSourcesRequestRequestTypeDef = TypedDict(
     "ListDataSourcesRequestRequestTypeDef",
     {
@@ -836,6 +859,14 @@ ListDomainNamesResponseTypeDef = TypedDict(
     },
 )
 
+ListFunctionsRequestListFunctionsPaginateTypeDef = TypedDict(
+    "ListFunctionsRequestListFunctionsPaginateTypeDef",
+    {
+        "apiId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListFunctionsRequestRequestTypeDef = TypedDict(
     "ListFunctionsRequestRequestTypeDef",
     {
@@ -854,6 +885,13 @@ ListFunctionsResponseTypeDef = TypedDict(
     },
 )
 
+ListGraphqlApisRequestListGraphqlApisPaginateTypeDef = TypedDict(
+    "ListGraphqlApisRequestListGraphqlApisPaginateTypeDef",
+    {
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListGraphqlApisRequestRequestTypeDef = TypedDict(
     "ListGraphqlApisRequestRequestTypeDef",
     {
@@ -871,6 +909,15 @@ ListGraphqlApisResponseTypeDef = TypedDict(
     },
 )
 
+ListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef = TypedDict(
+    "ListResolversByFunctionRequestListResolversByFunctionPaginateTypeDef",
+    {
+        "apiId": str,
+        "functionId": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListResolversByFunctionRequestRequestTypeDef = TypedDict(
     "ListResolversByFunctionRequestRequestTypeDef",
     {
@@ -890,6 +937,15 @@ ListResolversByFunctionResponseTypeDef = TypedDict(
     },
 )
 
+ListResolversRequestListResolversPaginateTypeDef = TypedDict(
+    "ListResolversRequestListResolversPaginateTypeDef",
+    {
+        "apiId": str,
+        "typeName": str,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListResolversRequestRequestTypeDef = TypedDict(
     "ListResolversRequestRequestTypeDef",
     {
@@ -924,6 +980,15 @@ ListTagsForResourceResponseTypeDef = TypedDict(
     },
 )
 
+ListTypesRequestListTypesPaginateTypeDef = TypedDict(
+    "ListTypesRequestListTypesPaginateTypeDef",
+    {
+        "apiId": str,
+        "format": TypeDefinitionFormatType,
+        "PaginationConfig": NotRequired["PaginatorConfigTypeDef"],
+    },
+)
+
 ListTypesRequestRequestTypeDef = TypedDict(
     "ListTypesRequestRequestTypeDef",
     {
